==> vue-code-generator-plugin-test-0.0.2.tgz: package/es/generator/plugins/component/vue3/vue.js <==
import _asyncToGenerator from "@babel/runtime/helpers/asyncToGenerator";
import _extends from "@babel/runtime/helpers/extends";
import _regeneratorRuntime from "@babel/runtime/regenerator";
import { ChunkType } from '@alilc/lowcode-code-generator';
import { VUE_CHUNK_NAME } from './const';
import CodeGen from '@alilc/lowcode-code-generator';
import { transformJsExpr } from './core/jsx/handlers/transformJsExpression';
import { transformThis2Context } from './core/jsx/handlers/transformThis2Context';
import { nodeToVue } from '../../../utils';
var _CodeGen$utils = CodeGen.utils,
  generateExpression = _CodeGen$utils.jsExpression.generateExpression,
  generateCompositeType = _CodeGen$utils.compositeType.generateCompositeType,
  Scope = _CodeGen$utils.scope.Scope;
var createReactNodeGenerator = nodeToVue.createReactNodeGenerator;
var pluginFactory = function pluginFactory(config) {
  var cfg = _extends({
    fileType: 'vue',
    // eslint-disable-next-line @typescript-eslint/consistent-type-assertions
    nodeTypeMapping: {}
  }, config);
  var nodeTypeMapping = cfg.nodeTypeMapping;
  var plugin = /*#__PURE__*/function () {
    var _ref = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee(pre) {
      var next, _next$contextData, _next$contextData$tol, tolerateEvalErrors, _next$contextData$eva, evalErrorsHandler, customHandlers, generatorPlugins, generator, ir, scope, jsxContent;
      return _regeneratorRuntime.wrap(function _callee$(_context) {
        while (1) switch (_context.prev = _context.next) {
          case 0:
            next = _extends({}, pre);
            _next$contextData = next.contextData, _next$contextData$tol = _next$contextData.tolerateEvalErrors, tolerateEvalErrors = _next$contextData$tol === void 0 ? true : _next$contextData$tol, _next$contextData$eva = _next$contextData.evalErrorsHandler, evalErrorsHandler = _next$contextData$eva === void 0 ? '' : _next$contextData$eva; // 这里会将内部的一些子上下文的访问(this.xxx)转换为 __$$context.xxx 的形式
            // 与 Rax 所不同的是，这里不会将最顶层的 this 转换掉
            customHandlers = {
              expression: function expression(input, scope, config) {
                var _config$tolerateEvalE;
                return transformJsExpr(generateExpression(input, scope), scope, {
                  dontWrapEval: !((_config$tolerateEvalE = config === null || config === void 0 ? void 0 : config.tolerateEvalErrors) !== null && _config$tolerateEvalE !== void 0 ? _config$tolerateEvalE : tolerateEvalErrors),
                  dontTransformThis2ContextAtRootScope: true
                });
              },
              "function": function _function(input, scope) {
                return transformThis2Context(generateCompositeType({
                  type: 'JSFunction',
                  value: input.value || 'function () {}'
                }, Scope.createRootScope()), scope, {
                  ignoreRootScope: true
                });
              }
            };
            generatorPlugins = {
              handlers: customHandlers,
              tagMapping: function tagMapping(v) {
                return nodeTypeMapping[v] || v;
              },
              tolerateEvalErrors: tolerateEvalErrors
            };
            generator = createReactNodeGenerator(generatorPlugins);
            ir = next.ir;
            scope = Scope.createRootScope();
            jsxContent = generator(ir, scope);
            next.chunks.push({
              type: ChunkType.STRING,
              fileType: cfg.fileType,
              name: VUE_CHUNK_NAME.ScriptStart,
              content: "<script setup>",
              linkAfter: []
            });
            next.chunks.push({
              type: ChunkType.STRING,
              fileType: cfg.fileType,
              name: VUE_CHUNK_NAME.ScriptContent,
              content: "console.log(\"\u6211\u662F\u811A\u672C\")",
              linkAfter: [VUE_CHUNK_NAME.ScriptStart]
            });
            next.chunks.push({
              type: ChunkType.STRING,
              fileType: cfg.fileType,
              name: VUE_CHUNK_NAME.ScriptEnd,
              content: "</script>",
              linkAfter: [VUE_CHUNK_NAME.ScriptContent]
            });
            next.chunks.push({
              type: ChunkType.STRING,
              fileType: cfg.fileType,
              name: VUE_CHUNK_NAME.TemplateStart,
              content: "<template>",
              linkAfter: [VUE_CHUNK_NAME.ScriptEnd]
            });
            next.chunks.push({
              type: ChunkType.STRING,
              fileType: cfg.fileType,
              name: VUE_CHUNK_NAME.TemplateContent,
              content: jsxContent,
              linkAfter: [VUE_CHUNK_NAME.TemplateStart]
            });
            next.chunks.push({
              type: ChunkType.STRING,
              fileType: cfg.fileType,
              name: VUE_CHUNK_NAME.TemplateEnd,
              content: "</template>",
              linkAfter: [VUE_CHUNK_NAME.TemplateContent]
            });
            next.chunks.push({
              type: ChunkType.STRING,
              fileType: cfg.fileType,
              name: VUE_CHUNK_NAME.StyleStart,
              content: "<style scoped>",
              linkAfter: [VUE_CHUNK_NAME.TemplateEnd]
            });
            next.chunks.push({
              type: ChunkType.STRING,
              fileType: cfg.fileType,
              name: VUE_CHUNK_NAME.StyleEnd,
              content: "</style>",
              linkAfter: [VUE_CHUNK_NAME.ScriptContent]
            });
            return _context.abrupt("return", next);
          case 17:
          case "end":
            return _context.stop();
        }
      }, _callee);
    }));
    return function plugin(_x) {
      return _ref.apply(this, arguments);
    };
  }();
  return plugin;
};
export default pluginFactory;

==> vue-code-generator-plugin-test-0.0.3.tgz: package/es/generator/plugins/component/vue3/vue.js <==
import _asyncToGenerator from "@babel/runtime/helpers/asyncToGenerator";
import _extends from "@babel/runtime/helpers/extends";
import _regeneratorRuntime from "@babel/runtime/regenerator";
import CodeGen, { ChunkType } from '@alilc/lowcode-code-generator';
import { VUE_CHUNK_NAME, linkAfter } from './const';
import { transformJsExpr } from './core/jsx/handlers/transformJsExpression';
import { transformThis2Context } from './core/jsx/handlers/transformThis2Context';
import { nodeToVue } from '../../../utils';
var _CodeGen$utils = CodeGen.utils,
  generateExpression = _CodeGen$utils.jsExpression.generateExpression,
  generateCompositeType = _CodeGen$utils.compositeType.generateCompositeType,
  Scope = _CodeGen$utils.scope.Scope;
var createReactNodeGenerator = nodeToVue.createReactNodeGenerator;
var pluginFactory = function pluginFactory(config) {
  var cfg = _extends({
    fileType: 'vue',
    // eslint-disable-next-line @typescript-eslint/consistent-type-assertions
    nodeTypeMapping: {}
  }, config);
  var nodeTypeMapping = cfg.nodeTypeMapping;
  var plugin = /*#__PURE__*/function () {
    var _ref = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee(pre) {
      var next, _next$contextData$tol, tolerateEvalErrors, customHandlers, generatorPlugins, generator, ir, scope, jsxContent;
      return _regeneratorRuntime.wrap(function _callee$(_context) {
        while (1) switch (_context.prev = _context.next) {
          case 0:
            next = _extends({}, pre);
            _next$contextData$tol = next.contextData.tolerateEvalErrors, tolerateEvalErrors = _next$contextData$tol === void 0 ? true : _next$contextData$tol; // 这里会将内部的一些子上下文的访问(this.xxx)转换为 __$$context.xxx 的形式
            // 与 Rax 所不同的是，这里不会将最顶层的 this 转换掉
            customHandlers = {
              // eslint-disable-next-line @typescript-eslint/no-shadow
              expression: function expression(input, scope, config) {
                var _config$tolerateEvalE;
                return transformJsExpr(generateExpression(input, scope), scope, {
                  dontWrapEval: !((_config$tolerateEvalE = config === null || config === void 0 ? void 0 : config.tolerateEvalErrors) !== null && _config$tolerateEvalE !== void 0 ? _config$tolerateEvalE : tolerateEvalErrors),
                  dontTransformThis2ContextAtRootScope: true
                });
              },
              "function": function _function(input, scope) {
                return transformThis2Context(generateCompositeType({
                  type: 'JSFunction',
                  value: input.value || 'function () {}'
                }, Scope.createRootScope()), scope, {
                  ignoreRootScope: true
                });
              }
            };
            generatorPlugins = {
              handlers: customHandlers,
              tagMapping: function tagMapping(v) {
                return nodeTypeMapping[v] || v;
              },
              tolerateEvalErrors: tolerateEvalErrors
            };
            generator = createReactNodeGenerator(generatorPlugins);
            ir = next.ir;
            scope = Scope.createRootScope();
            jsxContent = generator(ir, scope);
            next.chunks.push({
              type: ChunkType.STRING,
              fileType: cfg.fileType,
              name: VUE_CHUNK_NAME.ScriptStart,
              content: '<script setup>',
              linkAfter: []
            });
            next.chunks.push({
              type: ChunkType.STRING,
              fileType: cfg.fileType,
              name: VUE_CHUNK_NAME.ScriptContent,
              content: 'console.log("欢迎使用浪潮软件-网页设计器")',
              linkAfter: linkAfter(VUE_CHUNK_NAME.ScriptContent)
            });
            next.chunks.push({
              type: ChunkType.STRING,
              fileType: cfg.fileType,
              name: VUE_CHUNK_NAME.ScriptEnd,
              content: '</script>',
              linkAfter: linkAfter(VUE_CHUNK_NAME.ScriptEnd)
            });
            next.chunks.push({
              type: ChunkType.STRING,
              fileType: cfg.fileType,
              name: VUE_CHUNK_NAME.TemplateStart,
              content: '<template>',
              linkAfter: linkAfter(VUE_CHUNK_NAME.TemplateStart)
            });
            next.chunks.push({
              type: ChunkType.STRING,
              fileType: cfg.fileType,
              name: VUE_CHUNK_NAME.TemplateContent,
              content: jsxContent,
              linkAfter: linkAfter(VUE_CHUNK_NAME.TemplateContent)
            });
            next.chunks.push({
              type: ChunkType.STRING,
              fileType: cfg.fileType,
              name: VUE_CHUNK_NAME.TemplateEnd,
              content: '</template>',
              linkAfter: linkAfter(VUE_CHUNK_NAME.TemplateEnd)
            });
            next.chunks.push({
              type: ChunkType.STRING,
              fileType: cfg.fileType,
              name: VUE_CHUNK_NAME.StyleStart,
              content: '<style scoped>',
              linkAfter: linkAfter(VUE_CHUNK_NAME.StyleStart)
            });
            next.chunks.push({
              type: ChunkType.STRING,
              fileType: cfg.fileType,
              name: VUE_CHUNK_NAME.StyleEnd,
              content: '</style>',
              linkAfter: linkAfter(VUE_CHUNK_NAME.StyleEnd)
            });
            return _context.abrupt("return", next);
          case 17:
          case "end":
            return _context.stop();
        }
      }, _callee);
    }));
    return function plugin(_x) {
      return _ref.apply(this, arguments);
    };
  }();
  return plugin;
};
export default pluginFactory;
